﻿function Get-DNSConfiguration
{
    [CmdletBinding()]
    Param (
        [Parameter(Mandatory=$true, ValueFromPipeline=$true)]
        [String[]]$ComputerName
    )

    Process 
    {
      foreach ($computer in $ComputerName)
      {
        if (Test-Connection $Computer -Quiet -Count 1)
        {
          # récupération des interfaces réseaux actives
          $cnxActives = Get-WmiObject Win32_NetworkAdapter -Computer $Computer | 
                Where {$_.NetConnectionStatus -eq 2}

          # récupération de la configuration des interfaces réseaux actives
          $confActive = 
            Get-WmiObject Win32_NetworkAdapterConfiguration -Comp $Computer | 
               Where { ($_.index -eq $($cnxActives.index))  }
          $result = $confActive.DNSServerSearchOrder
          $Ping = 'OK'
        }
        else
        {
           $result = $null
           $Ping = 'NOK'
        }

        [PSCustomObject]@{ HostName = $computer
                           Ping     = $ping
                           DNS      = $result }
      }
    }
}