﻿function Set-DNSConfiguration
{
    [CmdletBinding()]
    Param (
        [Parameter(Mandatory=$true, ValueFromPipeline=$true)]
        [String[]]$ComputerName,
        [Parameter(Mandatory=$false)]
        [String[]]$DNSServerList = @('192.168.0.30', '192.168.0.40')
    )

    Process 
    {
        # récupération des interfaces réseaux actives
        $cnxActives = Get-WmiObject Win32_NetworkAdapter -Computer $ComputerName | 
           Where {$_.NetConnectionStatus -eq 2}

        # récupération de la configuration des interfaces réseaux actives
        $confActive = Get-WmiObject Win32_NetworkAdapterConfiguration -Comp $ComputerName | 
           Where { ($_.index -eq $($cnxActives.index))  }

        $result = $confActive.SetDNSServerSearchOrder($DNSServerList)

        if ($result.returnValue -eq 0) 
        {
           Write-Verbose "$ComputerName : Mise à jour DNS réussie" 
        }
        else
        {
           Write-Error "$ComputerName : Echec de la mise à jour DNS !" 
        }
    }
}